@@ -3,8 +3,7 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef EVENTVIEWS_CALENDARDECORATION_H
-#define EVENTVIEWS_CALENDARDECORATION_H
+#pragma once
 
 #include "eventviews_export.h"
 
@@ -53,7 +52,7 @@ public:
       Return a short text for a given date,
       usually only a few words.
     */
-    Q_REQUIRED_RESULT virtual QString shortText();
+    Q_REQUIRED_RESULT virtual QString shortText() const;
 
     /**
       Return a long text for a given date.
@@ -62,14 +61,14 @@ public:
 
       Can for example be used as a tool tip.
     */
-    Q_REQUIRED_RESULT virtual QString longText();
+    Q_REQUIRED_RESULT virtual QString longText() const;
 
     /**
       Return an extensive text for a given date.
       This text can be of any length,
       but usually it will have one or a few paragraphs.
     */
-    Q_REQUIRED_RESULT virtual QString extensiveText();
+    Q_REQUIRED_RESULT virtual QString extensiveText() const;
 
     /**
       Return a pixmap for a given date and a given size.
@@ -80,7 +79,7 @@ public:
       Return a URL pointing to more information about the content of the
       element.
      */
-    Q_REQUIRED_RESULT virtual QUrl url();
+    Q_REQUIRED_RESULT virtual QUrl url() const;
 
 Q_SIGNALS:
     void gotNewPixmap(const QPixmap &);
@@ -108,19 +107,19 @@ public:
     StoredElement(const QString &id, const QPixmap &pixmap);
 
     virtual void setShortText(const QString &t);
-    QString shortText() override;
+    Q_REQUIRED_RESULT QString shortText() const override;
 
     virtual void setLongText(const QString &t);
-    QString longText() override;
+    Q_REQUIRED_RESULT QString longText() const override;
 
     virtual void setExtensiveText(const QString &t);
-    QString extensiveText() override;
+    Q_REQUIRED_RESULT QString extensiveText() const override;
 
     virtual void setPixmap(const QPixmap &p);
-    virtual QPixmap pixmap();
+    Q_REQUIRED_RESULT virtual QPixmap pixmap() const;
 
     virtual void setUrl(const QUrl &u);
-    QUrl url() override;
+    Q_REQUIRED_RESULT QUrl url() const override;
 
 protected:
     QString mShortText;
@@ -140,6 +139,8 @@ protected:
  */
 class EVENTVIEWS_EXPORT Decoration : public CalendarSupport::Plugin
 {
+    Q_OBJECT
+
 public:
     static int interfaceVersion()
     {
@@ -153,7 +154,7 @@ public:
 
     using List = QList<Decoration *>;
 
-    Decoration();
+    Decoration(QObject *parent = nullptr, const QVariantList &args = {});
     ~Decoration() override;
 
     /**
@@ -224,17 +225,17 @@ protected:
     /**
       Map all dates of the same week to a single date.
     */
-    QDate weekDate(const QDate &date);
+    QDate weekDate(QDate date);
 
     /**
       Map all dates of the same month to a single date.
     */
-    QDate monthDate(const QDate &date);
+    QDate monthDate(QDate date);
 
     /**
       Map all dates of the same year to a single date.
     */
-    QDate yearDate(const QDate &date);
+    QDate yearDate(QDate date);
 
 private:
     QMap<QDate, Element::List> mDayElements;
@@ -243,13 +244,6 @@ private:
     QMap<QDate, Element::List> mYearElements;
 };
 
-class EVENTVIEWS_EXPORT DecorationFactory : public CalendarSupport::PluginFactory
-{
-    Q_OBJECT
-public:
-    Decoration *createPluginFactory() override = 0;
-};
 }
 }
 
-#endif
