@@ -12,7 +12,7 @@
 #include "prefs.h"
 #include "prefs_base.h" // Ugly, but needed for the Enums
 
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
@@ -205,17 +205,15 @@ int MonthItem::daySpan() const
 
 bool MonthItem::greaterThan(const MonthItem *e1, const MonthItem *e2)
 {
-    const QDate leftStartDate = e1->startDate();
-    const QDate rightStartDate = e2->startDate();
-
-    if (!leftStartDate.isValid() || !rightStartDate.isValid()) {
-        return false;
-    }
-
-    if (leftStartDate == rightStartDate) {
-        const int leftDaySpan = e1->daySpan();
-        const int rightDaySpan = e2->daySpan();
-        if (leftDaySpan == rightDaySpan) {
+    const int leftDaySpan = e1->daySpan();
+    const int rightDaySpan = e2->daySpan();
+    if (leftDaySpan == rightDaySpan) {
+        const QDate leftStartDate = e1->startDate();
+        const QDate rightStartDate = e2->startDate();
+        if (!leftStartDate.isValid() || !rightStartDate.isValid()) {
+            return false;
+        }
+        if (leftStartDate == rightStartDate) {
             if (e1->allDay() && !e2->allDay()) {
                 return true;
             }
@@ -224,11 +222,10 @@ bool MonthItem::greaterThan(const MonthItem *e1, const MonthItem *e2)
             }
             return e1->greaterThanFallback(e2);
         } else {
-            return leftDaySpan > rightDaySpan;
+            return leftStartDate > rightStartDate;
         }
     }
-
-    return leftStartDate > rightStartDate;
+    return leftDaySpan > rightDaySpan;
 }
 
 bool MonthItem::greaterThanFallback(const MonthItem *other) const
@@ -311,9 +308,7 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
     }
 }
 
-IncidenceMonthItem::~IncidenceMonthItem()
-{
-}
+IncidenceMonthItem::~IncidenceMonthItem() = default;
 
 bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 {
@@ -616,7 +611,7 @@ Akonadi::Item IncidenceMonthItem::akonadiItem() const
     if (mIncidence) {
         return monthScene()->mMonthView->calendar()->item(mIncidence);
     } else {
-        return Akonadi::Item();
+        return {};
     }
 }
 
@@ -670,25 +665,25 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
 //-----------------------------------------------------------------
 // HOLIDAYMONTHITEM
 HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, QDate date, const QString &name)
+    : HolidayMonthItem(monthScene, date, date, name)
+{
+}
+
+HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, QDate startDate, QDate endDate, const QString &name)
     : MonthItem(monthScene)
-    , mDate(date)
+    , mStartDate(startDate)
+    , mEndDate(endDate)
     , mName(name)
 {
 }
 
-HolidayMonthItem::~HolidayMonthItem()
-{
-}
+HolidayMonthItem::~HolidayMonthItem() = default;
 
 bool HolidayMonthItem::greaterThanFallback(const MonthItem *other) const
 {
     const auto o = qobject_cast<const HolidayMonthItem *>(other);
-    if (o) {
-        return MonthItem::greaterThanFallback(other);
-    }
-
     // always put holidays on top
-    return false;
+    return !o;
 }
 
 void HolidayMonthItem::finalizeMove(const QDate &newStartDate)
